subroutine check_g_real
    !check that KS wavefunctions are orthonormal
    !in G space
    !gamma only case
    !only for norm-conserving pseudo-potentials
    !no spin-polarised case

    use kinds, only : DP
    use io_global, only : stdout
    USE wavefunctions, ONLY : evc
    USE io_files, ONLY : prefix, tmp_dir, nwordwfc,iunwfc
    USE wvfct,                ONLY : nbnd, npwx, npw
    USE gvect,                ONLY :gstart
    USE mp_world,  ONLY :  world_comm
    USE mp, ONLY : mp_sum
    use io_global, ONLY : stdout, ionode

    implicit none

    real(kind=DP), allocatable :: omat(:,:)
    integer :: ii,jj

    integer ::iun
    INTEGER, EXTERNAL :: find_free_unit

    !read in wfc

    CALL davcio(evc,2*nwordwfc,iunwfc,1,0)

!   calculate overlap matrix
    allocate(omat(nbnd,nbnd))

    call dgemm('T','N',nbnd,nbnd,2*npw,2.d0,evc,2*npwx,evc,2*npwx,0.d0,omat,nbnd)
    if(gstart==2) then
        do ii=1,nbnd
            do jj=1,nbnd
                omat(jj,ii)=omat(jj,ii)-dble(conjg(evc(1,ii))*evc(1,jj))
            enddo
        enddo
    endif

    call mp_sum(omat, world_comm)

!write on screen
    do ii=1,nbnd
        do jj=1,nbnd
            write(stdout,*) 'OVERLAP:', ii,jj,omat(ii,jj)
        enddo
    enddo   

!write on disk
    iun = find_free_unit()
    if(ionode) then
        open(unit=iun,file='overlap.dat',status='unknown')
        do ii=1,nbnd
            do jj=1,nbnd
                write(iun,*)  ii,jj,omat(ii,jj)
            enddo
        enddo  
        close(iun)
    endif


    deallocate(omat)
    !

    return

end subroutine
